@@ -25,6 +25,7 @@
 
 #include <QStandardPaths>
 #include <QTimer>
+#include <QFileInfo>
 
 ExportBlogiloJob::ExportBlogiloJob(QObject *parent, Utils::StoredTypes typeSelected, ArchiveStorage *archiveStorage, int numberOfStep)
     : AbstractImportExportJob(parent, archiveStorage, typeSelected, numberOfStep)
@@ -69,8 +70,9 @@ void ExportBlogiloJob::slotCheckBackupData()
 
         const QString dbfileStr = QStringLiteral("blogilo.db");
         const QString dbfile = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QLatin1String("/blogilo/") + dbfileStr;
-
-        backupFile(dbfile, Utils::dataPath() +  QLatin1String("/blogilo/"), dbfileStr);
+        if (QFileInfo::exists(dbfile)) {
+            backupFile(dbfile, Utils::dataPath() +  QLatin1String("/blogilo/"), dbfileStr);
+        }
 
         Q_EMIT info(i18n("Data backup done."));
     }
