@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2015-2016 Montel Laurent <montel@kde.org>
+   Copyright (C) 2015-2017 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -26,7 +26,7 @@ class PimSettingsBackupRestoreUI : public PimSettingsBackupRestore
 {
     Q_OBJECT
 public:
-    explicit PimSettingsBackupRestoreUI(QWidget *parentWidget, QObject *parent = Q_NULLPTR);
+    explicit PimSettingsBackupRestoreUI(QWidget *parentWidget, QObject *parent = nullptr);
     ~PimSettingsBackupRestoreUI();
 
 protected:
